@@ -2,12 +2,11 @@
 
 #include <sys/stat.h>
 #include <libxfce4util/libxfce4util.h>
-#include <libxfce4util/i18n.h>
 #include <time.h>
 
+#include "plugin.h"
 #include "debug_print.h"
 #include "translate.h"
-#include "plugin.h"
 #include "http_client.h"
 #include "summary_window.h"
 #include "config_dialog.h"
@@ -44,7 +43,7 @@ gboolean check_envproxy(gchar **proxy_host, gint *proxy_port)
         }
 
         *proxy_host = g_strdup(split[0]);
-        *proxy_port = atoi(split[1]);
+        *proxy_port = (int)strtol(split[1], NULL, 0);
 
         g_strfreev(split);
 
@@ -74,15 +73,17 @@ gchar *make_label(struct xml_weather *weatherdata, enum datas opt, enum units un
                 default: lbl = "?"; break;
         }
 
-        switch (size)
-        {
-                case 2: txtsize = "medium"; break;
-                case 3: txtsize = "medium"; break;
-                default: txtsize="x-small"; break;
-        }
+        /* arbitrary, choose something that works */
+        if (size > 36)
+                txtsize = "medium";
+        else if (size > 30)
+                txtsize = "small";
+        else if (size > 24)     
+                txtsize = "x-small";
+        else
+                txtsize="xx-small";
 
         rawvalue = get_data(weatherdata, opt);
-        value = NULL;
 
         switch (opt)
         {
@@ -93,6 +94,9 @@ gchar *make_label(struct xml_weather *weatherdata, enum datas opt, enum units un
                 case WIND_SPEED:
                 case WIND_GUST: value = translate_wind_speed(rawvalue, unit);
                                 break;
+                default:
+                                value = NULL;
+                                break;
         }
 
        
@@ -109,25 +113,123 @@ gchar *make_label(struct xml_weather *weatherdata, enum datas opt, enum units un
 
         return str;
 }
-/* -1 error 0 no update needed 1 success */
+
+gchar *get_filename(const struct xfceweather_data *data)
+{
+        gchar *filename = 
+                g_strdup_printf("xfce4/weather-plugin/weather_%s_%c.xml", 
+                        data->location_code, data->unit == METRIC ? 'm' : 'i');
+        gchar *fullfilename = 
+                xfce_resource_save_location(XFCE_RESOURCE_CACHE, filename, 
+                                            TRUE);
+        g_free(filename);
+
+        return fullfilename;
+}
+
+void set_icon_error(struct xfceweather_data *data)
+{
+        GdkPixbuf *icon = get_icon(data->iconimage, "25", data->iconsize);
+        gtk_image_set_from_pixbuf(GTK_IMAGE(data->iconimage), icon);
+        g_object_unref (icon);
+
+        if (data->weatherdata)
+        {
+                xml_weather_free(data->weatherdata);
+                data->weatherdata = NULL;
+        }
+
+        gtk_tooltips_set_tip(data->tooltips, data->tooltipbox, 
+                             _("Cannot update weather data"), NULL);
+
+        return;
+}
+
+void set_icon_current(struct xfceweather_data *data)
+{
+        int i;
+        GdkPixbuf *icon;
+        for (i = 0; i < data->labels->len; i++)
+        {
+                enum datas opt;
+                gchar *str;
+
+                opt = g_array_index(data->labels, enum datas, i);
+               
+                str = make_label(data->weatherdata, opt, data->unit,
+                                data->size);
+
+                gtk_scrollbox_set_label(GTK_SCROLLBOX(data->scrollbox), -1, 
+                                str);
+                g_free(str);
+
+               
+        }
+
+        gtk_scrollbox_enablecb(GTK_SCROLLBOX(data->scrollbox), TRUE);       
+                
+        icon = get_icon(data->iconimage, get_data(data->weatherdata, WICON), data->iconsize);
+        gtk_image_set_from_pixbuf(GTK_IMAGE(data->iconimage), icon);
+        g_object_unref (icon);
+       
+        gtk_tooltips_set_tip (data->tooltips, data->tooltipbox, 
+                translate_desc(get_data(data->weatherdata, TRANS)), NULL);
+}
+
+void cb_update(gboolean status, gpointer user_data)
+{
+        struct xfceweather_data *data = (struct xfceweather_data *)user_data;
+        gchar *fullfilename = get_filename(data);
+        xmlDoc *doc;
+        xmlNode *cur_node;
+        struct xml_weather *weather;
+
+        if (!fullfilename)
+                return;
+        
+        doc = xmlParseFile(fullfilename);
+        g_free(fullfilename);
+
+        if (!doc)
+                return;
+
+        cur_node = xmlDocGetRootElement(doc);
+
+        if (cur_node)
+                weather = parse_weather(cur_node);
+
+        xmlFreeDoc(doc);
+
+        gtk_scrollbox_clear(GTK_SCROLLBOX(data->scrollbox));
+
+        if (weather)
+        {
+               
+                if (data->weatherdata)
+                        xml_weather_free(data->weatherdata);
+               
+                data->weatherdata = weather;
+                set_icon_current(data);
+        }
+        else
+        {
+                set_icon_error(data);
+                return;
+        }
+}
+
+/* -1 error 0 no update needed 1 updating */
 gint update_weatherdata(struct xfceweather_data *data, gboolean force)
 {
-        xmlNode *cur_node = NULL;
-        xmlDoc *doc = NULL;
-        struct xml_weather *weather = NULL;
-        gboolean ret;
         struct stat attrs; 
         /*gchar *fullfilename = xfce_resource_save_location(XFCE_RESOURCE_CACHE, 
                         filename, TRUE);*/
-        gchar *fullfilename, *filename;
+        gchar *fullfilename;
 
         if (!data->location_code)
                 return -1;
 
-        filename = g_strdup_printf("xfce4/weather-plugin/weather_%s_%c.xml", 
-                        data->location_code, data->unit == METRIC ? 'm' : 'i');
-        fullfilename = xfce_resource_save_location(XFCE_RESOURCE_CACHE, filename, TRUE);
-        g_free(filename);
+        fullfilename = get_filename(data);
 
         if (!fullfilename)
         {
@@ -143,106 +245,31 @@ gint update_weatherdata(struct xfceweather_data *data, gboolean force)
                                 data->unit == METRIC ? 'm' : 'i');
                
 
-                ret = http_get_file(url, "xoap.weather.com", fullfilename, 
-                                data->proxy_host, data->proxy_port);
+                gboolean status = http_get_file(url, "xoap.weather.com", fullfilename, 
+                                data->proxy_host, data->proxy_port, cb_update,
+                                (gpointer) data);
                 g_free(url);
+                g_free(fullfilename);
 
-                if (!ret)
-                {
-                        g_free(fullfilename);
-                       
-                        return -1;
-                }
+                return status ? 1 : -1;
         }
         else if (data->weatherdata)
                 return 0;
-      
-
-        doc = xmlParseFile(fullfilename);
-        g_free(fullfilename);
-
-        if (!doc)
-                return -1;
-
-       
-
-        cur_node = xmlDocGetRootElement(doc);
-
-        if (cur_node)
-                weather = parse_weather(cur_node);
-
-        xmlFreeDoc(doc);
-
-        if (weather)
+        else
         {
-               
-                if (data->weatherdata)
-                        xml_weather_free(data->weatherdata);
-               
-                data->weatherdata = weather;
+                cb_update(TRUE, data);
                 return 1;
         }
-        else
-                return -1;
-}       
+}
 
 void update_plugin (struct xfceweather_data *data, gboolean force)
 {
-        int i;
-        GdkPixbuf *icon = NULL; 
-       
-        gtk_scrollbox_clear(GTK_SCROLLBOX(data->scrollbox));
-        
         if (update_weatherdata(data, force) == -1)
         {
-                GdkPixbuf *icon = get_icon(data->iconimage, "25", data->iconsize);
-                gtk_image_set_from_pixbuf(GTK_IMAGE(data->iconimage), icon);
-
-                if (data->weatherdata)
-                {
-                        xml_weather_free(data->weatherdata);
-                        data->weatherdata = NULL;
-                }
-
-                add_tooltip(data->tooltipbox, "Cannot update weather data");
-                
-                return;
+                gtk_scrollbox_clear(GTK_SCROLLBOX(data->scrollbox));
+                set_icon_error(data);
         }
-
-       
-
-       
-
-        for (i = 0; i < data->labels->len; i++)
-        {
-                enum datas opt;
-                gchar *str;
-
-                opt = g_array_index(data->labels, enum datas, i);
-               
-                str = make_label(data->weatherdata, opt, data->unit,
-                                data->size);
-
-               
-
-                gtk_scrollbox_set_label(GTK_SCROLLBOX(data->scrollbox), -1, 
-                                str);
-                g_free(str);
-
-               
-        }
-
-        
-
-        gtk_scrollbox_enablecb(GTK_SCROLLBOX(data->scrollbox), TRUE);
-
-       
-                
-        icon = get_icon(data->iconimage, get_data(data->weatherdata, WICON), data->iconsize);
-       
-        gtk_image_set_from_pixbuf(GTK_IMAGE(data->iconimage), icon);
-       
-        add_tooltip(data->tooltipbox, translate_desc(get_data(data->weatherdata, TRANS)));
+        /* else update will be called through the callback in http_get_file() */
 }
 
 GArray *labels_clear (GArray *array)
@@ -258,23 +285,24 @@ GArray *labels_clear (GArray *array)
         return array;
 }
 
-void xfceweather_read_config (Control *control, xmlNodePtr node)
+void xfceweather_read_config (XfcePanelPlugin *plugin, struct xfceweather_data *data)
 {
-        gchar *value;
-        struct xfceweather_data *data = (struct xfceweather_data *)control->data;
-
-       
-
-        if (!node || !node->children)
-                return;
-
-        node = node->children;
-
-        if (!xmlStrEqual (node->name, (const xmlChar *) XFCEWEATHER_ROOT))
-                return;
-
-        value = xmlGetProp (node, (const xmlChar *) "loc_code");
+        char label[10];
+        int i;
+        const char *value;
+        char *file;
+        XfceRc *rc;
         
+        if (!(file = xfce_panel_plugin_lookup_rc_file (plugin)))
+                return;
+        
+        rc = xfce_rc_simple_open (file, TRUE);
+        g_free (file);
+        
+        if (!rc)
+                return;
+    
+        value = xfce_rc_read_entry (rc, "loc_code", NULL);
 
         if (value) 
         {
@@ -282,20 +310,13 @@ void xfceweather_read_config (Control *control, xmlNodePtr node)
                         g_free(data->location_code);
                 
                 data->location_code = g_strdup(value);
-                g_free(value); 
         }
 
-        value = xmlGetProp (node, (const xmlChar *) "celsius");
+        if (xfce_rc_read_bool_entry (rc, "celsius", TRUE))
+                data->unit = METRIC;
+        else
+                data->unit = IMPERIAL;
 
-        if (value) 
-        {
-                if (atoi(value) == 1)
-                        data->unit = IMPERIAL;
-                else
-                        data->unit = METRIC;
-                g_free(value);
-        }
-        
         if (data->proxy_host)
         {
                 g_free(data->proxy_host);
@@ -308,28 +329,19 @@ void xfceweather_read_config (Control *control, xmlNodePtr node)
                 data->saved_proxy_host = NULL;
         }
 
-        value = xmlGetProp (node, (const xmlChar *) "proxy_host");
+        value = xfce_rc_read_entry (rc, "proxy_host", NULL);
 
-        if (value)
+        if (value && *value)
         {
                 data->saved_proxy_host = g_strdup(value);
-                g_free(value);
         }
 
-        value = xmlGetProp (node, (const xmlChar *) "proxy_port");
+        data->saved_proxy_port = xfce_rc_read_int_entry (rc, "proxy_port", 0);
 
-        if (value)
-        {
-                data->saved_proxy_port = atoi(value);
-                g_free(value);
-        }
-
-        value = xmlGetProp(node, (const xmlChar *) "proxy_fromenv");
-
-        if (value && atoi(value))
-        {
+        data->proxy_fromenv = xfce_rc_read_bool_entry (rc, "proxy_fromenv", FALSE);
         
-                data->proxy_fromenv = TRUE;
+        if (data->proxy_fromenv)
+        {
                 check_envproxy(&data->proxy_host, &data->proxy_port); 
         }
         else
@@ -338,80 +350,80 @@ void xfceweather_read_config (Control *control, xmlNodePtr node)
                 data->proxy_port = data->saved_proxy_port;
         }
 
-
         data->labels = labels_clear(data->labels); 
         
-        for (node = node->children; node; node = node->next) {
-                if (node->type != XML_ELEMENT_NODE)
-                        continue;
+        for (i = 0; i < 100 /* arbitrary */; ++i) {
+                int val;
+                
+                g_snprintf (label, 10, "label%d", i);
 
-                if (NODE_IS_TYPE(node, "label_")) { /* label_ because the values of the
-                                                     previous plugin are invalid in this version * */
-                        value = DATA(node);
-                        if (value) {
-                                gint val = atoi(value); 
-                                g_array_append_val(data->labels, val);
-                                g_free(value);
-                        }
-                }
+                val = xfce_rc_read_int_entry (rc, label, -1);
+
+                if (val >= 0)
+                        g_array_append_val(data->labels, val);
+                else
+                        break;
         }
 
-       
-
-        update_plugin(data, FALSE);
+        xfce_rc_close (rc);
 }
 
-void xfceweather_write_config (Control *control,
-                xmlNodePtr parent)
+void xfceweather_write_config (XfcePanelPlugin *plugin, 
+                               struct xfceweather_data *data)
 {
-        xmlNodePtr root, node;
-        gchar *value;
+        char label[10];
         int i = 0;
+        XfceRc *rc;
+        char *file;
+        
+        if (!(file = xfce_panel_plugin_save_location (plugin, TRUE)))
+                return;
+        
+        /* get rid of old values */
+        unlink (file);
+        
+        rc = xfce_rc_simple_open (file, FALSE);
+        g_free (file);
+        
+        if (!rc)
+                return;    
 
-        struct xfceweather_data *data = (struct xfceweather_data *)control->data;
-
-        root = xmlNewTextChild (parent, NULL, XFCEWEATHER_ROOT, NULL);
-
-        value = g_strdup_printf("%d", data->unit == IMPERIAL ? 1 : 0);
-        xmlSetProp (root, "celsius", value);
-        g_free(value);
+        xfce_rc_write_bool_entry (rc, "celcius", (data->unit == METRIC));
 
         if (data->location_code)
-                xmlSetProp (root, "loc_code", data->location_code);
+                xfce_rc_write_entry (rc, "loc_code", data->location_code);
 
-        if (data->proxy_fromenv)
-                xmlSetProp(root, "proxy_fromenv", "1");
-        else if (data->proxy_host)
+        xfce_rc_write_bool_entry (rc, "proxy_fromenv", data->proxy_fromenv);
+        
+        if (data->proxy_host)
         {
-                xmlSetProp(root, "proxy_host", data->proxy_host);
+                xfce_rc_write_entry (rc, "proxy_host", data->proxy_host);
 
-                value = g_strdup_printf("%d", data->proxy_port);
-                xmlSetProp(root, "proxy_port", value);
-                g_free(value);
+                xfce_rc_write_int_entry (rc, "proxy_port", data->proxy_port);
         }
 
         for (i = 0; i < data->labels->len; i++) 
         {
-                enum datas opt = g_array_index (data->labels, enum datas, i);
-                value = g_strdup_printf("%d", opt);
+                g_snprintf (label, 10, "label%d", i);
 
-                node = xmlNewTextChild(root, NULL, "label_", value);
-                g_free(value);
+                xfce_rc_write_int_entry (rc, label, (int)g_array_index (data->labels, enum datas, i));
         }
+
+        xfce_rc_close (rc);
 }
 
 gboolean update_cb(struct xfceweather_data *data)
 {
-        XFCE_PANEL_LOCK();
+        DEBUG_PUTS("update_cb(): callback called\n");
         
         update_plugin(data, FALSE);
-        
-        XFCE_PANEL_UNLOCK();
+
+        DEBUG_PUTS("update_cb(): request added, returning\n");
         
         return TRUE;
 }
 
-void real_update_config(struct xfceweather_data *data, gboolean force)
+void update_plugin_with_reset(struct xfceweather_data *data, gboolean force)
 {
         if (data->updatetimeout)
                 g_source_remove(data->updatetimeout);
@@ -424,17 +436,14 @@ void real_update_config(struct xfceweather_data *data, gboolean force)
 
 void update_config(struct xfceweather_data *data)
 {
-        real_update_config(data, TRUE); /* force because units could have changed */
+        update_plugin_with_reset(data, TRUE); /* force because units could have changed */
 }
 
 void close_summary(GtkWidget *widget, gpointer *user_data)
 {
         struct xfceweather_data *data = (struct xfceweather_data *)user_data;
 
-       
-
         data->summary_window = NULL;
-       
 }
 
 gboolean cb_click(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
@@ -460,40 +469,89 @@ gboolean cb_click(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
                 }
         }
         else if (event->button == 2)
-                real_update_config(data, TRUE);
+                update_plugin_with_reset(data, TRUE);
 
         return FALSE;
 }
 
 
-void xfceweather_create_options(Control *control, GtkContainer *container,
-                GtkWidget *done)
+static void xfceweather_dialog_response (GtkWidget *dlg, int response, 
+                struct xfceweather_dialog *dialog)
 {
-        struct xfceweather_data *data = (struct xfceweather_data *)control->data;
-        struct xfceweather_dialog *dialog = create_config_dialog(data, container, done);
+        struct xfceweather_data *data = dialog->wd;
+        
+        apply_options (dialog);
+            
+        gtk_widget_destroy (dlg);
+        xfce_panel_plugin_unblock_menu (data->plugin);
+        xfceweather_write_config (data->plugin, data);
+}
+
+void xfceweather_create_options(XfcePanelPlugin *plugin, struct xfceweather_data *data)
+{
+        GtkWidget *dlg, *header, *vbox;
+        struct xfceweather_dialog *dialog;
+        
+        xfce_panel_plugin_block_menu (plugin);
+
+        dlg = gtk_dialog_new_with_buttons (_("Properties"), 
+                GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
+                GTK_DIALOG_DESTROY_WITH_PARENT |
+                GTK_DIALOG_NO_SEPARATOR,
+                GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+                NULL);
+
+        gtk_container_set_border_width (GTK_CONTAINER (dlg), 2);
+
+        header = xfce_create_header (NULL, _("Weather Update"));
+        gtk_widget_set_size_request (GTK_BIN (header)->child, -1, 32);
+        gtk_container_set_border_width (GTK_CONTAINER (header), BORDER - 2);
+        gtk_widget_show (header);
+        gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), header,
+                            FALSE, TRUE, 0);
+
+        vbox = gtk_vbox_new(FALSE, BORDER);
+        gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER - 2);
+        gtk_widget_show(vbox);
+        gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), vbox,
+                            TRUE, TRUE, 0);
+    
+        dialog = create_config_dialog(data, vbox);
+
+        g_signal_connect (dlg, "response", G_CALLBACK (xfceweather_dialog_response),
+                          dialog);
 
         set_callback_config_dialog(dialog, update_config);
+
+        gtk_widget_show (dlg);
 }
        
 
-gboolean xfceweather_create_control(Control *control)
+struct xfceweather_data *xfceweather_create_control(XfcePanelPlugin *plugin)
 {
         struct xfceweather_data *data = g_new0(struct xfceweather_data, 1);
-        GtkWidget *vbox, *vbox2;
+        GtkWidget *vbox;
         enum datas lbl;
+        GdkPixbuf *icon;
 
         if (!IconSizeSmall)
-                IconSizeSmall = gtk_icon_size_register("iconsize_small", 20, 20);
+                IconSizeSmall = gtk_icon_size_register("iconsize_small", 16, 16);
+
+        data->plugin = plugin;
+
+        data->tooltips = gtk_tooltips_new ();
+        g_object_ref (data->tooltips);
+        gtk_object_sink (GTK_OBJECT (data->tooltips));
 
         data->scrollbox = gtk_scrollbox_new();
        
-        data->iconimage = gtk_image_new_from_pixbuf(get_icon(control->base, "-", IconSizeSmall));
+        icon = get_icon(GTK_WIDGET (plugin), "-", IconSizeSmall);
+        data->iconimage = gtk_image_new_from_pixbuf(icon);
         gtk_misc_set_alignment(GTK_MISC(data->iconimage), 0.5, 1);
-       
+        g_object_unref (icon);
 
         data->labels = g_array_new(FALSE, TRUE, sizeof(enum datas));
        
-       
         vbox = gtk_vbox_new(FALSE, 0);
 
         gtk_box_pack_start(GTK_BOX(vbox), data->iconimage, TRUE, FALSE, 0);
@@ -501,37 +559,32 @@ gboolean xfceweather_create_control(Control *control)
 
         data->tooltipbox = gtk_event_box_new();
         gtk_container_add(GTK_CONTAINER(data->tooltipbox), vbox);
+        gtk_widget_show_all(data->tooltipbox);
         
-        vbox2 = gtk_vbox_new(FALSE, 0);
-        gtk_box_pack_start(GTK_BOX(vbox2), data->tooltipbox, FALSE, FALSE, 0);
+        xfce_panel_plugin_add_action_widget (plugin, data->tooltipbox);
 
-        gtk_container_add(GTK_CONTAINER(control->base), vbox2);
-        g_signal_connect(data->tooltipbox, "button-press-event", G_CALLBACK(cb_click), (gpointer)data);
-        
-        gtk_widget_show_all(vbox2);
+        g_signal_connect(data->tooltipbox, "button-press-event", 
+                        G_CALLBACK(cb_click), (gpointer)data);
 
+        /* assign to tempval because g_array_append_val() is using & operator */
         lbl = FLIK;
         g_array_append_val(data->labels, lbl);
         lbl = TEMP;
         g_array_append_val(data->labels, lbl);
 
-        control->data = data;
-        control->with_popup = FALSE;
-        
         /* FIXME Without this the first label looks odd, because 
          * the gc isn't created yet */
         gtk_scrollbox_set_label(GTK_SCROLLBOX(data->scrollbox), -1, "1");
         gtk_scrollbox_clear(GTK_SCROLLBOX(data->scrollbox));
 
-        data->updatetimeout = gtk_timeout_add(UPDATE_TIME * 1000, (GSourceFunc)update_cb, data);    
+        data->updatetimeout = 
+                gtk_timeout_add(UPDATE_TIME * 1000, (GSourceFunc)update_cb, data);    
 
-        return TRUE;
+        return data;
 }
 
-void xfceweather_free(Control *control)
+void xfceweather_free(XfcePanelPlugin *plugin, struct xfceweather_data *data)
 {
-        struct xfceweather_data *data = (struct xfceweather_data *)control->data;
-
         if (data->weatherdata)
                 xml_weather_free(data->weatherdata);
 
@@ -542,9 +595,7 @@ void xfceweather_free(Control *control)
         }
         
         g_free(data->location_code);
-/*      XXX the buffer is shared amoung all instances of the plugin, 
- *      so it causes an segv when freeing it */
-/*        free_get_data_buffer();  */
+        free_get_data_buffer();  
         
         g_array_free(data->labels, TRUE);
 
@@ -553,58 +604,61 @@ void xfceweather_free(Control *control)
         g_free (data);
 }
 
-void xfceweather_attach_callback (Control *control, const gchar *signal, GCallback cb,
-                gpointer data)
+gboolean xfceweather_set_size(XfcePanelPlugin *panel, int size, 
+                              struct xfceweather_data *data)
 {
-        struct xfceweather_data *datae = (struct xfceweather_data*) control->data;
-
-        g_signal_connect(datae->tooltipbox, signal, cb, data);
-}
-
-void xfceweather_set_size(Control *control, gint size)
-{
-        struct xfceweather_data *data = (struct xfceweather_data *)control->data;
-
         data->size = size;
 
-        switch (data->size)
-        {
-                case 0: data->iconsize = IconSizeSmall; break;
-                case 1: data->iconsize = GTK_ICON_SIZE_LARGE_TOOLBAR; break;
-                case 2: data->iconsize = GTK_ICON_SIZE_DND; break;
-                case 3: data->iconsize = GTK_ICON_SIZE_DIALOG; break; 
-        }
+        /* arbitrary, choose something that works */
+        if (size <= 30)
+                data->iconsize = IconSizeSmall;
+        else if (size <= 36)
+                data->iconsize = GTK_ICON_SIZE_BUTTON;
+        else if (size <= 48)
+                data->iconsize = GTK_ICON_SIZE_LARGE_TOOLBAR;
+        else
+                data->iconsize = GTK_ICON_SIZE_DND;
 
         update_plugin(data, FALSE);
+
+        return TRUE;
 }
 
-G_MODULE_EXPORT void
-xfce_control_class_init (ControlClass * cc)
+static void
+weather_construct (XfcePanelPlugin *plugin)
 {
         char *path;
+        struct xfceweather_data *data;
 
         xfce_textdomain(GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
-
-        cc->name = "weather";
-        cc->caption = _("Weather update");
-
-        cc->create_control = (CreateControlFunc) xfceweather_create_control;
-        cc->attach_callback = xfceweather_attach_callback;
-        cc->read_config = xfceweather_read_config;
-        cc->write_config = xfceweather_write_config;
-
-        cc->create_options = xfceweather_create_options;
-        cc->free = xfceweather_free;
-        cc->set_size = xfceweather_set_size;
-
-        /* prevent widgets from being installed twice */
-        control_class_set_unloadable (cc, FALSE);
-
+        
         path = g_strdup_printf("%s%s%s%s", THEMESDIR, G_DIR_SEPARATOR_S,
                         DEFAULT_W_THEME, G_DIR_SEPARATOR_S);
         register_icons(path);
         g_free(path);
 
+        data = xfceweather_create_control (plugin);
+        
+        xfceweather_read_config (plugin, data);
+
+        xfceweather_set_size (plugin, xfce_panel_plugin_get_size (plugin), 
+                              data);
+        
+        gtk_container_add (GTK_CONTAINER (plugin), data->tooltipbox);
+        
+        g_signal_connect (plugin, "free-data", G_CALLBACK (xfceweather_free), 
+                          data);
+        
+        g_signal_connect (plugin, "save", 
+                          G_CALLBACK (xfceweather_write_config), data);
+        
+        g_signal_connect (plugin, "size-changed", 
+                          G_CALLBACK (xfceweather_set_size), data);
+
+        xfce_panel_plugin_menu_show_configure (plugin);
+        g_signal_connect (plugin, "configure-plugin", 
+                          G_CALLBACK (xfceweather_create_options), data);
 }
 
-XFCE_PLUGIN_CHECK_INIT
+XFCE_PANEL_PLUGIN_REGISTER_EXTERNAL (weather_construct);
+
