@@ -1,17 +1,22 @@
 #ifndef PLUGIN_H
 #define PLUGIN_H
 
-#include <panel/plugins.h>
-#include <gdk/gdk.h>
+#include <gtk/gtk.h>
+#include <libxfce4panel/xfce-panel-plugin.h>
 
 #include "parsers.h"
 #include "get_data.h"
 
 #define XFCEWEATHER_ROOT "weather"
 #define DEFAULT_W_THEME "liquid"
-#define UPDATE_TIME 1800
+#define UPDATE_TIME 1600
+#define BORDER 8
 
 struct xfceweather_data {
+        XfcePanelPlugin *plugin;
+
+	GtkTooltips *tooltips;
+
         GtkWidget *scrollbox;
         GtkWidget *iconimage;
         GtkWidget *tooltipbox;
