@@ -33,15 +33,11 @@ gboolean draw_up (GtkScrollbox *self)
         GdkRectangle update_rect = {0,0, GTK_WIDGET(self)->allocation.width, 
                 GTK_WIDGET(self)->allocation.height};
         
-        XFCE_PANEL_LOCK();
-
         if (self->draw_offset == 0) 
         {
                 self->draw_timeout = g_timeout_add(LABEL_REFRESH,
                                 (GSourceFunc)start_draw_down, self);
                 
-                XFCE_PANEL_UNLOCK();
-                
                 return FALSE;
         }
         else
@@ -49,8 +45,6 @@ gboolean draw_up (GtkScrollbox *self)
         
         gtk_widget_draw(GTK_WIDGET(self), &update_rect);
 
-        XFCE_PANEL_UNLOCK();
-        
         return TRUE;
 }
 
@@ -59,15 +53,11 @@ gboolean draw_down (GtkScrollbox *self)
         GdkRectangle update_rect = {0, 0, GTK_WIDGET(self)->allocation.width, 
                 GTK_WIDGET(self)->allocation.height};
 
-        XFCE_PANEL_LOCK();
-
         if (self->draw_offset == self->draw_maxoffset) 
         {
                 self->draw_timeout = 0;
                 start_draw_up(self);
 
-                XFCE_PANEL_UNLOCK();
-                
                 return FALSE;
         }
         else
@@ -75,8 +65,6 @@ gboolean draw_down (GtkScrollbox *self)
         
         gtk_widget_draw(GTK_WIDGET(self), &update_rect);
 
-        XFCE_PANEL_UNLOCK();
-        
         return TRUE;
 }
 
@@ -85,13 +73,9 @@ void start_draw_up(GtkScrollbox *self)
         gint width, height;
         struct label *lbl;
         static int i = 0;
-        GtkWidget *widget = (GtkWidget *)self;
-
-        XFCE_PANEL_LOCK();
 
         if (self->labels->len == 0)
 	{
-                XFCE_PANEL_UNLOCK();
                 return;
 	}
 
@@ -111,7 +95,6 @@ void start_draw_up(GtkScrollbox *self)
 			if (self->draw_timeout)
 				stop_callback(self);
         		self->draw_timeout = g_timeout_add(LABEL_SPEED, (GSourceFunc)start_draw_up, self);
-                	XFCE_PANEL_UNLOCK();
 			return;
 		}
 	}
@@ -125,7 +108,6 @@ void start_draw_up(GtkScrollbox *self)
                 self->draw_offset = 0;
                 
                 gtk_widget_draw(GTK_WIDGET(self), &update_rect);
-		XFCE_PANEL_UNLOCK();
                 return;
         }
         
@@ -135,18 +117,12 @@ void start_draw_up(GtkScrollbox *self)
         self->draw_timeout = g_timeout_add(LABEL_SPEED, (GSourceFunc)draw_up, self);
 
         i++;
-
-	XFCE_PANEL_UNLOCK();
 }
 
 gboolean start_draw_down (GtkScrollbox *self)
 {
-        XFCE_PANEL_LOCK();
-        
         self->draw_timeout = g_timeout_add(LABEL_SPEED, (GSourceFunc)draw_down, self);
 
-        XFCE_PANEL_UNLOCK();
-        
         return FALSE;
 }
 void stop_callback(GtkScrollbox *self)
@@ -154,7 +130,7 @@ void stop_callback(GtkScrollbox *self)
         if (self->draw_timeout == 0)
                 return;
 
-        DEBUG_PRINT("remove\n", NULL);
+        DEBUG_PUTS("remove\n");
 
         g_source_remove(self->draw_timeout);
         self->draw_timeout = 0;
@@ -173,7 +149,6 @@ GdkPixmap *make_pixmap(GtkScrollbox *self, gchar *value)
 {
         GdkWindow *rootwin;
         PangoLayout *pl;
-        GdkGC *gc;
         gint width, height, middle;
         GdkPixmap *pixmap;
         GtkRequisition widgsize = {0, }; 
@@ -188,7 +163,6 @@ GdkPixmap *make_pixmap(GtkScrollbox *self, gchar *value)
 
         pl = gtk_widget_create_pango_layout(widget, NULL);
         pango_layout_set_markup(pl, value, -1);
-        gc = gdk_gc_new(GDK_DRAWABLE(rootwin));
 
         pango_layout_get_pixel_size(pl, &width, &height);
 
@@ -198,10 +172,9 @@ GdkPixmap *make_pixmap(GtkScrollbox *self, gchar *value)
                         widget->style->bg_gc[0],
                         TRUE, 0, 0, width, height);
 
-        gdk_draw_layout(GDK_DRAWABLE(pixmap), gc, 0, 0, pl);
+        gdk_draw_layout(GDK_DRAWABLE(pixmap), widget->style->fg_gc[0], 0, 0, pl);
 
         g_object_unref(pl);
-        g_object_unref(gc);
 
         gtk_widget_size_request(widget, &widgsize);
 
